@@ -371,10 +371,11 @@ enum
 #define MUTT_EDIT_HEADERS_RESUME      2
 
 /* flags to _mutt_select_file() */
-#define MUTT_SEL_BUFFY  (1<<0)
-#define MUTT_SEL_MULTI  (1<<1)
-#define MUTT_SEL_FOLDER (1<<2)
-#define MUTT_SEL_DIRECTORY (1<<3)  /* Allow directories to be selected
+#define MUTT_SEL_BUFFY     (1<<0)
+#define MUTT_SEL_MULTI     (1<<1)
+#define MUTT_SEL_MAILBOX   (1<<2)  /* Use LastMailboxDir state */
+#define MUTT_SEL_FILE      (1<<3)  /* Use LastFileDir state */
+#define MUTT_SEL_DIRECTORY (1<<4)  /* Allow directories to be selected
                                     * via <view-file> */
 
 /* flags for parse_spam_list */
@@ -649,6 +650,7 @@ enum
   OPTIGNOREMACROEVENTS, /* (pseudo) don't process macro/push/exec events while set */
   OPTAUTOCRYPTGPGME,    /* (pseudo) use Autocrypt context inside crypt-gpgme.c */
   OPTMENUPOPCLEARSCREEN, /* (pseudo) clear the screen when popping the last menu. */
+  OPTMANUALABORT,       /* (pseudo) indicates user manually aborted an operation */
 
   OPTMAX
 };
